import rclpy
from rclpy.node import Node
import tf2_ros
import geometry_msgs.msg as gm


class TF2PublisherNode(Node):

    def __init__(self):
        super().__init__('tf2_publisher_node')
        self.tf_broadcaster = tf2_ros.TransformBroadcaster(self)
        
        self.timer = self.create_timer(0.1, self.publish_identity_transform)

        self.x = 0.0

    def publish_identity_transform(self):
        transform_stamped = gm.TransformStamped()
        transform_stamped.header.stamp = self.get_clock().now().to_msg()
        transform_stamped.header.frame_id = 'odom'
        transform_stamped.child_frame_id = 'base_link'

        # Identity transform (no translation, no rotation)
        transform_stamped.transform.translation.x = self.x
        transform_stamped.transform.translation.y = 0.0
        transform_stamped.transform.translation.z = 0.0
        transform_stamped.transform.rotation.x = 0.0
        transform_stamped.transform.rotation.y = 0.0
        transform_stamped.transform.rotation.z = 0.0
        transform_stamped.transform.rotation.w = 1.0


        self.x += 0.01

        self.tf_broadcaster.sendTransform(transform_stamped)

        transform_stamped = gm.TransformStamped()
        transform_stamped.header.stamp = self.get_clock().now().to_msg()
        transform_stamped.header.frame_id = 'base_link'
        transform_stamped.child_frame_id = 'velodyne'

        # Identity transform (no translation, no rotation)
        transform_stamped.transform.translation.x = 0.0
        transform_stamped.transform.translation.y = self.x
        transform_stamped.transform.translation.z = 0.0
        transform_stamped.transform.rotation.x = 0.0
        transform_stamped.transform.rotation.y = 0.0
        transform_stamped.transform.rotation.z = 0.0
        transform_stamped.transform.rotation.w = 1.0

        self.tf_broadcaster.sendTransform(transform_stamped)

      


        self.get_logger().info('Published identity transform')

def main(args=None):
    rclpy.init(args=args)

    tf2_publisher = TF2PublisherNode()
    rclpy.spin(tf2_publisher)

    tf2_publisher.destroy_node()
    rclpy.shutdown()


if __name__ == '__main__':
    main()
